opening_hours API documentation

# opening_hours

A library for parsing and working with OSM's opening hours field. You can find its specification here and the reference JS library here.

Note that the specification is quite messy and that the JS library takes liberty to extend it quite a lot. This means that most of the real world data don't actually comply to the very restrictive grammar detailed in the official specification. This library tries to fit with the real world data while remaining as close as possible to the core specification.

The main structure you will have to interact with is OpeningHours, which represents a parsed definition of opening hours.

def validate(oh, /)

Validate that input string is a correct opening hours description.

###### Examples

    >>> opening_hours.validate("24/7")
    True
    >>> opening_hours.validate("24/24")
    False

class OpeningHours:

Parse input opening hours description.

###### Raises

- SyntaxError: Given string is not in valid opening hours format.

###### Examples

    >>> oh = OpeningHours("24/7")
    >>> oh.is_open()
    True

OpeningHours()
def state(self, time=None, /)

Get current state of the time domain, the state can be either "open", "closed" or "unknown".

###### Parameters

- time (Optional[datetime]): Base time for the evaluation, current time will be used if it is not specified.

###### Examples

    >>> OpeningHours("24/7 off").state()
    'closed'

def is_open(self, time=None, /)

Check if current state is open.

###### Parameters

- time (Optional[datetime]): Base time for the evaluation, current time will be used if it is not specified.

###### Examples

    >>> OpeningHours("24/7").is_open()
    True

def is_closed(self, time=None, /)

Check if current state is closed.

###### Parameters

- time (Optional[datetime]): Base time for the evaluation, current time will be used if it is not specified.

###### Examples

    >>> OpeningHours("24/7 off").is_closed()
    True

def is_unknown(self, time=None, /)

Check if current state is unknown.

###### Parameters

- time (Optional[datetime]): Base time for the evaluation, current time will be used if it is not specified.

###### Examples

    >>> OpeningHours("24/7 unknown").is_unknown()
    True

def next_change(self, time=None, /)

Get the date for next change of state. If the date exceed the limit date, returns None.

###### Parameters

- time (Optional[datetime]): Base time for the evaluation, current time will be used if it is not specified.

###### Examples

    >>> OpeningHours("24/7").next_change() # None
    >>> OpeningHours("2099Mo-Su 12:30-17:00").next_change()
    datetime.datetime(2099, 1, 1, 12, 30)

def intervals(self, start=None, end=None, /)

Give an iterator that yields successive time intervals of consistent state.

###### Parameters

- start (Optional[datetime]): Initial time for the iterator, current time will be used if it is not specified.
- end (Optional[datetime]): Maximal time for the iterator, the iterator will continue until year 9999 if it no max is specified.

###### Examples

    >>> intervals = OpeningHours("2099Mo-Su 12:30-17:00").intervals()
    >>> next(intervals)
    (..., datetime.datetime(2099, 1, 1, 12, 30), 'closed', [])
    >>> next(intervals)
    (datetime.datetime(2099, 1, 1, 12, 30), datetime.datetime(2099, 1, 1, 17, 0), 'open', [])